package server

import (
	"flag"
	"fmt"
	"git.smsvc.net/pomodoro/GoTomato/internal/shared"
	"git.smsvc.net/pomodoro/GoTomato/internal/websocket"
	"git.smsvc.net/pomodoro/GoTomato/pkg/models"
	"log"
	"net/http"
)

func Start() {
	// Define CLI flags for ListenAddress and ListenPort
	listenAddress := flag.String("listenAddress", shared.DefaultServerConfig.ListenAddress, "IP address to listen on")
	listenPort := flag.Int("listenPort", shared.DefaultServerConfig.ListenPort, "Port to listen on")
	password := flag.String("password", "", "Control password for pomodoro session (optional)")
	flag.Parse()

	serverConfig := models.GoTomatoServerConfig{
		ListenAddress: *listenAddress,
		ListenPort:    *listenPort,
	}
	shared.PomodoroPassword = *password

	listen := fmt.Sprintf("%s:%d", serverConfig.ListenAddress, serverConfig.ListenPort)

	http.HandleFunc("/ws", websocket.HandleConnections)
	go websocket.SendPermanentBroadCastMessage()

	log.Printf("Pomodoro WebSocket server started on %s\n", listen)
	err := http.ListenAndServe(listen, nil)
	if err != nil {
		log.Fatalf("Error starting server: %v", err)
	}
}
